GTextField class
Generic text form field with named constructors for common form inputs.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- GTextField
Constructors
- GTextField({Key? key, required GTextFieldConfig config, bool obscurable = false, GTextFieldConfig resolveConfig(BuildContext context, GTextFieldConfig config)?})
-
const
-
GTextField.confirmPassword({Key? key, String? name, TextEditingController? controller, String? initialValue, TextEditingController? passwordController, String? passwordName, String label = 'Confirm password', String hint = 'Re-enter your password', TextInputAction textInputAction = TextInputAction.done, List<
TextInputFormatter> ? inputFormatters, ConfirmPasswordValidationConfig validationConfig = const ConfirmPasswordValidationConfig(), ValidationMessageResolver<ConfirmPasswordValidationIssue> validationMessageResolver = resolveConfirmPasswordValidationIssue, GFormValidator? validator, GTextFieldConfig configure(GTextFieldConfig config)?, void onChanged(String)?, void onFieldSubmitted(String)?, void onSaved(String?)?, IconData? prefixIcon, FocusNode? focusNode, AutovalidateMode? autovalidateMode, bool? enabled, bool readOnly = false, int? maxLength, TextAlign textAlign = TextAlign.start, TextStyle? style, Iterable<String> ? autofillHints = const [AutofillHints.password], InputDecoration? decoration}) -
factory
-
GTextField.email({Key? key, String? name, TextEditingController? controller, String? initialValue, String label = 'Email', String hint = 'Enter your email', TextInputAction textInputAction = TextInputAction.next, List<
TextInputFormatter> ? inputFormatters, EmailValidationConfig validationConfig = const EmailValidationConfig(), ValidationMessageResolver<EmailValidationIssue> validationMessageResolver = resolveEmailValidationIssue, GFormValidator? validator, GTextFieldConfig configure(GTextFieldConfig config)?, void onChanged(String)?, void onFieldSubmitted(String)?, void onSaved(String?)?, IconData? prefixIcon, FocusNode? focusNode, AutovalidateMode? autovalidateMode, bool? enabled, bool readOnly = false, int? maxLength, TextAlign textAlign = TextAlign.start, TextStyle? style, Iterable<String> ? autofillHints = const [AutofillHints.email], InputDecoration? decoration}) -
factory
-
GTextField.number({Key? key, String? name, TextEditingController? controller, String? initialValue, String label = 'Number', String? hint, TextInputAction textInputAction = TextInputAction.next, List<
TextInputFormatter> ? inputFormatters, NumberValidationConfig validationConfig = const NumberValidationConfig(allowNegative: false, integerOnly: true), ValidationMessageResolver<NumberValidationIssue> validationMessageResolver = resolveNumberValidationIssue, GFormValidator? validator, GTextFieldConfig configure(GTextFieldConfig config)?, void onChanged(String)?, void onFieldSubmitted(String)?, void onSaved(String?)?, IconData? prefixIcon, FocusNode? focusNode, AutovalidateMode? autovalidateMode, bool? enabled, bool readOnly = false, int? maxLength, TextAlign textAlign = TextAlign.start, TextStyle? style, Iterable<String> ? autofillHints, InputDecoration? decoration}) -
factory
-
GTextField.password({Key? key, String? name, TextEditingController? controller, String? initialValue, String label = 'Password', String hint = 'Enter your password', TextInputAction textInputAction = TextInputAction.done, List<
TextInputFormatter> ? inputFormatters, PasswordValidationConfig validationConfig = const PasswordValidationConfig(), ValidationMessageResolver<PasswordValidationIssue> validationMessageResolver = resolvePasswordValidationIssue, GFormValidator? validator, GTextFieldConfig configure(GTextFieldConfig config)?, void onChanged(String)?, void onFieldSubmitted(String)?, void onSaved(String?)?, IconData? prefixIcon, FocusNode? focusNode, AutovalidateMode? autovalidateMode, bool? enabled, bool readOnly = false, int? maxLength, TextAlign textAlign = TextAlign.start, TextStyle? style, Iterable<String> ? autofillHints = const [AutofillHints.password], InputDecoration? decoration}) -
factory
-
GTextField.text({Key? key, String? name, TextEditingController? controller, String? initialValue, String label = 'Text', String? hint, TextInputType keyboardType = TextInputType.text, TextInputAction textInputAction = TextInputAction.next, List<
TextInputFormatter> ? inputFormatters, TextValidationConfig validationConfig = const TextValidationConfig(), ValidationMessageResolver<TextValidationIssue> validationMessageResolver = resolveTextValidationIssue, GFormValidator? validator, GTextFieldConfig configure(GTextFieldConfig config)?, void onChanged(String)?, void onFieldSubmitted(String)?, void onSaved(String?)?, IconData? prefixIcon, FocusNode? focusNode, AutovalidateMode? autovalidateMode, bool? enabled, bool readOnly = false, int? minLines, int? maxLines = 1, int? maxLength, TextCapitalization textCapitalization = TextCapitalization.none, TextAlign textAlign = TextAlign.start, TextStyle? style, Iterable<String> ? autofillHints, InputDecoration? decoration}) -
factory
Properties
- config → GTextFieldConfig
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- obscurable → bool
-
final
- resolveConfig → GTextFieldConfig Function(BuildContext context, GTextFieldConfig config)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited