ConfirmPasswordValidationConfig class final
Configuration for confirm-password validation.
Constructors
- ConfirmPasswordValidationConfig({bool requireConfirmation = true, bool trimWhitespace = false})
-
Creates a confirm-password validation config.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- requireConfirmation → bool
-
Whether an empty confirmation is allowed.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- trimWhitespace → bool
-
Whether both values should be trimmed before comparison.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited