GForm class
Thin wrapper around Flutter's Form that uses a GFormController.
Provides the controller to descendants via controllerOf / maybeControllerOf so named gmana_form fields can resolve their text controllers automatically.
- Inheritance
Constructors
-
GForm({Key? key, required GFormController controller, required Widget child, AutovalidateMode? autovalidateMode, bool canPop = true, PopInvokedWithResultCallback<
Object?> ? onPopInvokedWithResult, void onChanged()?}) -
Creates a GForm bound to
controller.const
Properties
- autovalidateMode → AutovalidateMode?
-
See Form.autovalidateMode.
final
- canPop → bool
-
See Form.canPop.
final
- child → Widget
-
The child widget — usually a column of gmana_form fields.
final
- controller → GFormController
-
Controller that owns the form key and named text controllers.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onChanged → void Function()?
-
See Form.onChanged.
final
-
onPopInvokedWithResult
→ PopInvokedWithResultCallback<
Object?> ? -
See Form.onPopInvokedWithResult.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
controllerOf(
BuildContext context) → GFormController -
Like maybeControllerOf but throws a FlutterError when no GForm
is found above
context. Use this from widgets that require a form. -
maybeControllerOf(
BuildContext context) → GFormController? -
Looks up the nearest enclosing GFormController, or
nullif none.